@@ -583,7 +583,7 @@ class Ice_d18O():
         psl_ann = self.pobj.clim[self.psl_name].annualize()
 
         # sensor model
-        d18O_ice = ice_sensor(self.pobj.clim[self.pr_name].time, self.pobj.clim[self.d18O_name].da.values, self.pobj.clim[pr_name].da.values)
+        d18O_ice = ice_sensor(self.pobj.clim[self.pr_name].time, self.pobj.clim[self.d18O_name].da.values, self.pobj.clim[self.pr_name].da.values)
 
         # diffuse model
         if nproc is None: nproc = cpu_count()
