@@ -505,17 +505,19 @@ def showfig(fig, close=True):
         if True, close the figure automatically
 
     '''
-    if in_notebook:
-        try:
-            from IPython.display import display
-        except ImportError as error:
-            # Output expected ImportErrors.
-            print(f'{error.__class__.__name__}: {error.message}')
+    # if in_notebook:
+    #     try:
+    #         from IPython.display import display
+    #     except ImportError as error:
+    #         # Output expected ImportErrors.
+    #         print(f'{error.__class__.__name__}: {error.message}')
 
-        display(fig)
+    #     display(fig)
 
-    else:
-        plt.show()
+    # else:
+    #     plt.show()
+
+    plt.show()
 
     if close:
         closefig(fig)
@@ -528,11 +530,6 @@ def closefig(fig=None):
     fig : matplotlib.pyplot.figure
         The matplotlib figure object
 
-    See Also
-    --------
-    pyleoclim.utils.plotting.savefig : saves a figure to a specific path
-    pyleoclim.utils.plotting.in_notebook: Functions to sense a notebook environment
-
     '''
     if fig is not None:
         plt.close(fig)
@@ -555,10 +552,6 @@ def savefig(fig, path=None, settings={}, verbose=True):
           if the suffix is not given in "path", it will follow "format"
         - "format" can be one of {"pdf", "eps", "png", "ps"}
         
-    See Also
-    --------
-    
-    pyleoclim.utils.plotting.showfig : returns a visual of the figure. 
     '''
     if path is None and 'path' not in settings:
         raise ValueError('"path" must be specified, either with the keyword argument or be specified in `settings`!')
@@ -608,8 +601,6 @@ def set_style(style='journal', font_scale=1.0):
         Default is 1. Corresponding to 12 Font Size. 
     
     '''
-    mpl.rcParams.update(mpl.rcParamsDefault)
-
     font_dict = {
         'font.size': 12,
         'axes.labelsize': 12,
@@ -688,11 +679,8 @@ def set_style(style='journal', font_scale=1.0):
             'xtick.minor.width': 0,
             'ytick.minor.width': 0,
         })
-    elif 'matplotlib' in style or 'default' in style:
-        mpl.rcParams.update(mpl.rcParamsDefault)
     else:
-        print(f'Style [{style}] not availabel! Setting to `matplotlib` ...')
-        mpl.rcParams.update(mpl.rcParamsDefault)
+        raise ValueError(f'Style [{style}] not availabel!')
 
     if '_spines' in style:
         style_dict.update({
@@ -1083,4 +1071,66 @@ def make_lb(name, unit):
         lb = f'{name} [{unit}]'
     else:
         lb = f'{name}'
-    return lb
\ No newline at end of file
+    return lb
+
+def plot_scatter_map(values, lats, lons, levels=None,
+    figsize=(12, 6), projection='Robinson', transform=ccrs.PlateCarree(),
+    ax=None, proj_args=None, central_longitude=0, stock_img=True, marker='o', ms=200, edge_clr='w', title=None, title_fs=20,
+    cmap='Reds', vmin=None, vmax=None, clim=None, cmap_under=None, cmap_over=None, cbar=True, cbar_ticks=None, cbar_labels=None, cbar_orientation='vertical',
+    cbar_pad=0.05, cbar_extend='neither', cbar_fraction=0.15, cbar_shrink=0.5,
+    cbar_title=None, cbar_title_x=0.5, cbar_title_y=1.05, cbar_aspect=10,
+    gridlines=True, gl_labels=False, gl_top_lbs=False, gl_right_lbs=False):
+
+    proj_args = {} if proj_args is None else proj_args
+    proj_args_default = {'central_longitude': central_longitude}
+    proj_args_default.update(proj_args)
+    projection = CartopySettings.projection_dict[projection](**proj_args_default)
+
+    if ax is None:
+        fig = plt.figure(figsize=figsize)
+        ax = fig.add_subplot(projection=projection)
+
+    if stock_img:
+        ax.stock_img()
+
+    if title is not None:
+        ax.set_title(title, fontweight='bold', fontsize=title_fs)
+
+    cmap = plt.get_cmap(cmap)
+    if cmap_under is not None:
+        cmap.set_under(cmap_under)
+    if cmap_over is not None:
+        cmap.set_over(cmap_over)
+
+    if levels is not None:
+        norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
+    else:
+        norm = None
+
+    im = ax.scatter(lons, lats, s=ms, c=values, zorder=99, norm=norm,
+        edgecolor=edge_clr, marker=marker, cmap=cmap, vmin=vmin, vmax=vmax, transform=transform)
+
+    if clim is not None:
+        im.set_clim(clim)
+
+    if cbar:
+        cbar = plt.colorbar(im, ax=ax,
+            orientation=cbar_orientation, pad=cbar_pad, aspect=cbar_aspect, extend=cbar_extend,
+            fraction=cbar_fraction, shrink=cbar_shrink)
+        if cbar_ticks is not None:
+            cbar.set_ticks(cbar_ticks)
+        if cbar_labels is not None:
+            cbar.set_ticklabels(cbar_labels)
+        if cbar_title:
+            cbar.ax.set_title(cbar_title, x=cbar_title_x, y=cbar_title_y)
+
+    if gridlines:
+        gl = ax.gridlines(draw_labels=gl_labels)
+        gl.top_labels = gl_top_lbs
+        gl.right_labels = gl_right_lbs
+        
+
+    if 'fig' in locals():
+        return fig, ax
+    else:
+        return ax
\ No newline at end of file
